==> hapic-0.61.tar.gz: hapic-0.61/hapic/data.py <==
# -*- coding: utf-8 -*-
import typing
import urllib.parse


class HapicData(object):
    def __init__(self):
        self.body = {}
        self.path = {}
        self.query = {}
        self.headers = {}
        self.forms = {}
        self.files = {}


class HapicFile(object):
    def __init__(
        self,
        file_path: typing.Optional[str] = None,
        file_object: typing.Any = None,
        mimetype: typing.Any = None,
        filename: str = None,
        as_attachment: bool = False,
    ):
        self.file_path = file_path
        self.file_object = file_object
        self.filename = filename
        self.mimetype = mimetype
        self.as_attachment = as_attachment

    def get_content_disposition_header_value(self) -> str:
        disposition = 'inline'
        if self.as_attachment:
            disposition = 'attachment'
        if self.filename:
            # INFO - G.M - 2018-10-26 - deal correctly with unicode filename
            # see rfc6266 for more info.
            ascii_filename = self.filename.encode('ascii', 'replace').decode()
            # INFO - G.M - 2018-10-30 - Format correctly unicode.
            # encoding is needed for correct unicode character support,
            # Percent-encoding is best pratices, see also rfc5987.
            urlencoded_unicode_filename = urllib.parse.quote(self.filename)

            disposition = '{}; filename="{}"; filename*=UTF-8\'\'{};'.format(
                disposition,
                ascii_filename,
                urlencoded_unicode_filename,
            )
        return disposition

==> hapic-0.66.tar.gz: hapic-0.66/hapic/data.py <==
# -*- coding: utf-8 -*-
import typing
import urllib.parse


class HapicData(object):
    def __init__(self):
        self.body = {}
        self.path = {}
        self.query = {}
        self.headers = {}
        self.forms = {}
        self.files = {}


class HapicFile(object):
    def __init__(
        self,
        file_path: typing.Optional[str] = None,
        file_object: typing.Any = None,
        mimetype: typing.Any = None,
        filename: str = None,
        as_attachment: bool = False,
    ):
        self.file_path = file_path
        self.file_object = file_object
        self.filename = filename
        self.mimetype = mimetype
        self.as_attachment = as_attachment

    def get_content_disposition_header_value(self) -> str:
        disposition = "inline"
        if self.as_attachment:
            disposition = "attachment"
        if self.filename:
            # INFO - G.M - 2018-10-26 - deal correctly with unicode filename
            # see rfc6266 for more info.
            ascii_filename = self.filename.encode("ascii", "replace").decode()
            # INFO - G.M - 2018-10-30 - Format correctly unicode.
            # encoding is needed for correct unicode character support,
            # Percent-encoding is best pratices, see also rfc5987.
            urlencoded_unicode_filename = urllib.parse.quote(self.filename)

            disposition = "{}; filename=\"{}\"; filename*=UTF-8''{};".format(
                disposition, ascii_filename, urlencoded_unicode_filename
            )
        return disposition
